Documentation
¶
Index ¶
- Constants
- Variables
- func Kind(kind string) schema.GroupKind
- func RegisterDeepCopies(scheme *runtime.Scheme) errordeprecated
- func Resource(resource string) schema.GroupResource
- type Client
- type Interface
- type NetworkPoliciesGetter
- type NetworkPolicyController
- type NetworkPolicyHandlerFunc
- type NetworkPolicyInterface
- type NetworkPolicyLifecycle
- type NetworkPolicyList
- type NetworkPolicyLister
Constants ¶
const ( GroupName = "networking.k8s.io" Version = "v1" )
Variables ¶
var ( NetworkPolicyGroupVersionKind = schema.GroupVersionKind{ Version: Version, Group: GroupName, Kind: "NetworkPolicy", } NetworkPolicyResource = metav1.APIResource{ Name: "networkpolicies", SingularName: "networkpolicy", Namespaced: true, Kind: NetworkPolicyGroupVersionKind.Kind, } )
var ( SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes) AddToScheme = SchemeBuilder.AddToScheme )
var SchemeGroupVersion = schema.GroupVersion{Group: GroupName, Version: Version}
SchemeGroupVersion is group version used to register these objects
Functions ¶
func RegisterDeepCopies
deprecated
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns a Group qualified GroupResource
Types ¶
type Client ¶
func (*Client) NetworkPolicies ¶
func (c *Client) NetworkPolicies(namespace string) NetworkPolicyInterface
func (*Client) RESTClient ¶
type Interface ¶
type Interface interface {
RESTClient() rest.Interface
controller.Starter
NetworkPoliciesGetter
}
type NetworkPoliciesGetter ¶
type NetworkPoliciesGetter interface {
NetworkPolicies(namespace string) NetworkPolicyInterface
}
type NetworkPolicyController ¶
type NetworkPolicyController interface {
Informer() cache.SharedIndexInformer
Lister() NetworkPolicyLister
AddHandler(name string, handler NetworkPolicyHandlerFunc)
AddClusterScopedHandler(name, clusterName string, handler NetworkPolicyHandlerFunc)
Enqueue(namespace, name string)
Sync(ctx context.Context) error
Start(ctx context.Context, threadiness int) error
}
type NetworkPolicyHandlerFunc ¶
func NewNetworkPolicyLifecycleAdapter ¶
func NewNetworkPolicyLifecycleAdapter(name string, clusterScoped bool, client NetworkPolicyInterface, l NetworkPolicyLifecycle) NetworkPolicyHandlerFunc
type NetworkPolicyInterface ¶
type NetworkPolicyInterface interface {
ObjectClient() *objectclient.ObjectClient
Create(*v1.NetworkPolicy) (*v1.NetworkPolicy, error)
GetNamespaced(namespace, name string, opts metav1.GetOptions) (*v1.NetworkPolicy, error)
Get(name string, opts metav1.GetOptions) (*v1.NetworkPolicy, error)
Update(*v1.NetworkPolicy) (*v1.NetworkPolicy, error)
Delete(name string, options *metav1.DeleteOptions) error
DeleteNamespaced(namespace, name string, options *metav1.DeleteOptions) error
List(opts metav1.ListOptions) (*NetworkPolicyList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
DeleteCollection(deleteOpts *metav1.DeleteOptions, listOpts metav1.ListOptions) error
Controller() NetworkPolicyController
AddHandler(name string, sync NetworkPolicyHandlerFunc)
AddLifecycle(name string, lifecycle NetworkPolicyLifecycle)
AddClusterScopedHandler(name, clusterName string, sync NetworkPolicyHandlerFunc)
AddClusterScopedLifecycle(name, clusterName string, lifecycle NetworkPolicyLifecycle)
}
type NetworkPolicyLifecycle ¶
type NetworkPolicyList ¶
type NetworkPolicyList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []v1.NetworkPolicy
}
func (*NetworkPolicyList) DeepCopy ¶
func (in *NetworkPolicyList) DeepCopy() *NetworkPolicyList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NetworkPolicyList.
func (*NetworkPolicyList) DeepCopyInto ¶
func (in *NetworkPolicyList) DeepCopyInto(out *NetworkPolicyList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*NetworkPolicyList) DeepCopyObject ¶
func (in *NetworkPolicyList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
Click to show internal directories.
Click to hide internal directories.